==> nextcloud-app-mail-0.7.10-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/pt_BR.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "E-mail",
    "Loading accounts" : "Carregando contas",
    "Error while loading the accounts." : "Erro ao carregar as contas.",
    "Error while loading the selected account." : "Erro ao carregar a conta selecionada",
    "Can not load this folder." : "Não foi possível carregar esta pasta.",
    "Searching for {query}" : "Pesquisando por {query}",
    "Error while deleting message." : "Erro ao excluir mensagem.",
    "Forwarded message" : "Mensagem encaminhada",
    "Choose a folder to store the attachment in" : "Escolha uma pasta para armazenar os anexos",
    "Attachments saved to Files." : "Anexo salvos em Arquivos.",
    "Attachment saved to Files." : "Anexo salvo em Arquivos.",
    "Error while saving attachments to Files." : "Erro ao salvar anexos em Arquivos.",
    "Error while saving attachment to Files." : "Erro ao salvar anexos em Arquivos.",
    "Message flag could not be set." : "Marcação da mensagem não pôde ser definida.",
    "Could not move message." : "Não foi possível mover a mensagem.",
    "Invalid account" : "Conta inválida",
    "Invalid folder" : "Pasta inválida",
    "Error while creating the account: " : "Erro ao criar a conta:",
    "Unknown error" : "Erro desconhecido",
    "Error while updating the account: " : "Erro ao atualizar a conta:",
    "All inboxes" : "Todas as caixas de entrada",
    "you" : "você",
    "Send message to {email}" : "Enviar mensagem para {email}",
    "Could not load {tag}{name}{endtag}" : "Não foi possível carregar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Ocorreu um problema ao carregar {tag}{name}{endtag}",
    "Could not load your message" : "Não foi possível carregar sua mensagem",
    "Could not load the desired message" : "Não foi possível carregar a mensagem desejada",
    "Could not load the message" : "Não foi possível carregar a mensagem",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nova mensagem \nde {from}","%n novas mensagens \nde {from}"],
    "Nextcloud Mail" : "Email Nextcloud",
    "Save" : "Salvar",
    "Saved" : "Salvo",
    "Show all folders" : "Mostrar todas as pastas",
    "Collapse folders" : "Esconder as pastas",
    "Error while deleting account." : "Erro ao excluir a conta.",
    "Choose a file to add as attachment" : "Escolha um arquivo para adicionar como anexo",
    "An error occurred while uploading {fname}" : "Um erro ocorreu ao enviar {fname}",
    "Reply" : "Responder",
    "Send" : "Enviar",
    "Sending …" : "Enviando...",
    "Message sent!" : "Mensagem enviada!",
    "Server error" : "Erro no servidor",
    "An unknown error occurred" : "Ocorreu um erro desconhecido",
    "Opening HTML drafts is not supported yet." : "A abertura de rascunhos do HTML ainda não é suportada.",
    "No writable calendars found" : "Não foi encontrado nenhum calendário que possa ser editado",
    "Error while importing the calendar event" : "Erro ao importar o evento de calendário",
    "Error while downloading calendar event" : "Erro ao baixar evento de calendário",
    "& others" : "& outros",
    "Error while loading messages." : "Erro ao carregar mensagens.",
    "Error while refreshing messages." : "Erro ao atualizar as mensagens.",
    "Setting up your account" : "Configurando sua conta",
    "Inbox" : "Caixa de Entrada",
    "Sent" : "Enviados",
    "Drafts" : "Rascunhos",
    "Archive" : "Arquivados",
    "Trash" : "Lixeira",
    "Junk" : "Lixo",
    "All" : "Todos",
    "Favorites" : "Favoritos",
    "Auto detect failed. Please use manual mode." : "A auto detecção falhou. Por favor use o modo manual.",
    "Updating account failed: " : "Falhou ao atualizar a conta:",
    "Creating account failed: " : "A criação de contas falhou:",
    "Delete permanently" : "Excluir permanentemente",
    "Error loading message" : "Erro carregando mensagem",
    "Settings" : "Configurações",
    "Forwarding to %s" : "Encaminhando para %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se você não for redirecionado automaticamente em alguns segundos",
    "Redirect" : "Redirecionar",
    "The link leads to %s" : "O link leva a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se você não quiser visitar essa página, você pode retornar ao <a href=\"%s\">e-mail</a>.",
    "Continue to %s" : "Continue para %s",
    "Delete account" : "Excluir conta",
    "Try again" : "Tentar novamente",
    "New message" : "Nova mensagem",
    "Account Settings" : "Configurações de conta",
    "Aliases" : "Apelido",
    "Mail address" : "Endereço de e-mail",
    "Display Name" : "Nome",
    "Account" : "Conta",
    "Keyboard shortcuts" : "Atalhos de teclado",
    "Speed up your Mail experience with these quick shortcuts." : "Acelere o uso de seu e-mail com estes atalhos rápidos.",
    "Compose new message" : "Redigir nova mensagem",
    "Newer message" : "Mensagem mais recente",
    "Older message" : "Mensagem mais antiga",
    "Toggle star" : "Alterna para estrela",
    "Toggle unread" : "Alterna para não lido",
    "Delete" : "Excluir",
    "Search" : "Pesquisar",
    "Refresh" : "Atualizar",
    "Connect your mail account" : "Conectar sua conta de e-mail",
    "Name" : "Nome",
    "Mail Address" : "Endereço de e-mail",
    "Password" : "Senha",
    "Manual configuration" : "Configuração manual",
    "IMAP Host" : "Host IMAP",
    "IMAP security" : "Segurança IMAP",
    "None" : "Não",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porto IMAP",
    "IMAP User" : "Usuário IMAP",
    "IMAP Password" : "Senha IMAP",
    "SMTP Host" : "Host SMTP",
    "SMTP security" : "Segurança SMTP",
    "SMTP Port" : "Porto SMTP",
    "SMTP User" : "Usuário SMTP",
    "SMTP Password" : "Senha SMTP",
    "Connect" : "Conectar",
    "from" : "de",
    "to" : "para",
    "cc" : "cc",
    "bcc" : "cco",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Observe que o email veio de um endereço no-reply então sua resposta provavelmente não será lida.",
    "Subject" : "Assunto",
    "Save all to Files" : "Salvar tudo para Arquivos",
    "Add mail account" : "Adicionar conta de e-mail",
    "Use Gravatar and favicon avatars" : "Usar Gravatar e avatares para favicon",
    "No search results for" : "Nenhum resultado de busca para",
    "The images have been blocked to protect your privacy." : "As imagens foram bloqueadas para proteger sua privacidade",
    "Show images from this sender" : "Mostre imagens desse remetente",
    "Forward" : "Encaminhar",
    "No messages in this folder!" : "Sem mensagens nesta pasta!",
    "Upload attachment" : "Enviar anexo",
    "Add attachment from Files" : "Adicionar anexo a partir de arquivos",
    "Import into calendar" : "Importar para o calendário",
    "Download attachment" : "Baixar anexo",
    "Save to Files" : "Salvar para arquivos"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-mail-0.8.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/pt_BR.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Email",
    "Loading accounts" : "Carregando contas",
    "Error while loading the accounts." : "Erro ao carregar as contas.",
    "Can not load this folder." : "Não foi possível carregar esta pasta.",
    "Searching for {query}" : "Pesquisando por {query}",
    "Error while deleting message." : "Erro ao excluir mensagem.",
    "Forwarded message" : "Mensagem encaminhada",
    "Choose a folder to store the attachment in" : "Escolha uma pasta para armazenar os anexos",
    "Attachments saved to Files." : "Anexo salvos em Arquivos.",
    "Attachment saved to Files." : "Anexo salvo em Arquivos.",
    "Error while saving attachments to Files." : "Erro ao salvar anexos em Arquivos.",
    "Error while saving attachment to Files." : "Erro ao salvar anexos em Arquivos.",
    "Message flag could not be set." : "Marcação da mensagem não pôde ser definida.",
    "Could not move message." : "Não foi possível mover a mensagem.",
    "Invalid account" : "Conta inválida",
    "Invalid folder" : "Pasta inválida",
    "Error while creating the account: " : "Erro ao criar a conta:",
    "Unknown error" : "Erro desconhecido",
    "Error while updating the account: " : "Erro ao atualizar a conta:",
    "All inboxes" : "Todas as caixas de entrada",
    "you" : "você",
    "Send message to {email}" : "Enviar mensagem para {email}",
    "Could not load {tag}{name}{endtag}" : "Não foi possível carregar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Ocorreu um problema ao carregar {tag}{name}{endtag}",
    "Could not load your message" : "Não foi possível carregar sua mensagem",
    "Could not load the desired message" : "Não foi possível carregar a mensagem desejada",
    "Could not load the message" : "Não foi possível carregar a mensagem",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nova mensagem \nde {from}","%n novas mensagens \nde {from}"],
    "Nextcloud Mail" : "Email Nextcloud",
    "Save" : "Salvar",
    "Saved" : "Salvo",
    "Show all folders" : "Mostrar todas as pastas",
    "Collapse folders" : "Esconder as pastas",
    "Error while deleting account." : "Erro ao excluir a conta.",
    "Choose a file to add as attachment" : "Escolha um arquivo para adicionar como anexo",
    "An error occurred while uploading {fname}" : "Um erro ocorreu ao enviar {fname}",
    "Reply" : "Responder",
    "Send" : "Enviar",
    "Sending …" : "Enviando...",
    "Message sent!" : "Mensagem enviada!",
    "Server error" : "Erro no servidor",
    "An unknown error occurred" : "Ocorreu um erro desconhecido",
    "Opening HTML drafts is not supported yet." : "A abertura de rascunhos do HTML ainda não é suportada.",
    "No writable calendars found" : "Não foi encontrado nenhum calendário que possa ser editado",
    "Error while importing the calendar event" : "Erro ao importar o evento de calendário",
    "Error while downloading calendar event" : "Erro ao baixar evento de calendário",
    "& others" : "& outros",
    "Error while loading messages." : "Erro ao carregar mensagens.",
    "Error while refreshing messages." : "Erro ao atualizar as mensagens.",
    "Setting up your account" : "Configurando sua conta",
    "Inbox" : "Caixa de Entrada",
    "Sent" : "Enviados",
    "Drafts" : "Rascunhos",
    "Archive" : "Arquivados",
    "Trash" : "Lixeira",
    "Junk" : "Lixo",
    "All" : "Todos",
    "Favorites" : "Favoritos",
    "Auto detect failed. Please use manual mode." : "A auto detecção falhou. Por favor use o modo manual.",
    "Updating account failed: " : "Falhou ao atualizar a conta:",
    "Creating account failed: " : "A criação de contas falhou:",
    "Delete permanently" : "Excluir permanentemente",
    "Error loading message" : "Erro carregando mensagem",
    "Settings" : "Configurações",
    "Forwarding to %s" : "Encaminhando para %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se você não for redirecionado automaticamente em alguns segundos",
    "Redirect" : "Redirecionar",
    "The link leads to %s" : "O link leva a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se você não quiser visitar essa página, você pode retornar ao <a href=\"%s\">email</a>.",
    "Continue to %s" : "Continue para %s",
    "Delete account" : "Excluir conta",
    "Try again" : "Tentar novamente",
    "New message" : "Nova mensagem",
    "Account Settings" : "Configurações de conta",
    "Aliases" : "Apelido",
    "Mail address" : "Endereço de email",
    "Display Name" : "Nome",
    "Account" : "Conta",
    "Keyboard shortcuts" : "Atalhos de teclado",
    "Speed up your Mail experience with these quick shortcuts." : "Acelere o uso de seu email com estes atalhos rápidos.",
    "Compose new message" : "Redigir nova mensagem",
    "Newer message" : "Mensagem mais recente",
    "Older message" : "Mensagem mais antiga",
    "Toggle star" : "Alterna para estrela",
    "Toggle unread" : "Alterna para não lido",
    "Delete" : "Excluir",
    "Search" : "Pesquisar",
    "Refresh" : "Atualizar",
    "Connect your mail account" : "Conectar sua conta de email",
    "Name" : "Nome",
    "Mail Address" : "Endereço de email",
    "Password" : "Senha",
    "Manual configuration" : "Configuração manual",
    "IMAP Host" : "Host IMAP",
    "IMAP security" : "Segurança IMAP",
    "None" : "Não",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Porto IMAP",
    "IMAP User" : "Usuário IMAP",
    "IMAP Password" : "Senha IMAP",
    "SMTP Host" : "Host SMTP",
    "SMTP security" : "Segurança SMTP",
    "SMTP Port" : "Porto SMTP",
    "SMTP User" : "Usuário SMTP",
    "SMTP Password" : "Senha SMTP",
    "Connect" : "Conectar",
    "from" : "de",
    "to" : "para",
    "cc" : "cc",
    "bcc" : "cco",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Observe que o email veio de um endereço no-reply então sua resposta provavelmente não será lida.",
    "Subject" : "Assunto",
    "Save all to Files" : "Salvar tudo para Arquivos",
    "Add mail account" : "Adicionar conta de email",
    "Use Gravatar and favicon avatars" : "Usar Gravatar e avatares para favicon",
    "No search results for" : "Nenhum resultado de busca para",
    "The images have been blocked to protect your privacy." : "As imagens foram bloqueadas para proteger sua privacidade",
    "Show images from this sender" : "Mostre imagens desse remetente",
    "Forward" : "Encaminhar",
    "No messages in this folder" : "Sem mensagens nesta pasta",
    "Upload attachment" : "Enviar anexo",
    "Add attachment from Files" : "Adicionar anexo a partir de arquivos",
    "Import into calendar" : "Importar para o calendário",
    "Download attachment" : "Baixar anexo",
    "Save to Files" : "Salvar para arquivos"
},
"nplurals=2; plural=(n > 1);");
